from concordancer.server import download_query_interface

download_query_interface(force=True)